@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: reducers
 version: 3.12.1
-id: reducers-3.12.1-945b6d2d7be706517694521697039a82
-key: reduc_HXx20efBhAzKy1M6WN1ue1
+id: reducers-3.12.1-e18fca3ee2096c40c88476933be83bab
+key: reduc_Gn2M0Gstb7pICyyIqSOqLI
 license: BSD3
 copyright: Copyright (C) 2008-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/reducers-3.12.1
-hs-libraries: HSreducers-3.12.1-HXx20efBhAzKy1M6WN1ue1
+hs-libraries: HSreducers-3.12.1-Gn2M0Gstb7pICyyIqSOqLI
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -34,8 +34,8 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    semigroupoids-5.0.1-8eb2d2c8f0f0def85cbb7c35538a003a
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
